package com.bpcl.lpg.core.sftp;

import java.io.InputStream;
import java.io.ByteArrayInputStream;
import java.util.Iterator;
import java.util.Vector;
import java.util.HashSet;
import java.util.Set;
import com.jcraft.jsch.SftpException;
import com.jcraft.jsch.JSchException;
import com.jcraft.jsch.Session;
import com.jcraft.jsch.JSch;
import java.util.Properties;
import com.jcraft.jsch.ChannelSftp;
import org.apache.log4j.Logger;

public class SFTPService
{
    private static final Logger LOG;
    private static final String STRICT_HOST_KEY_CHECKING = "StrictHostKeyChecking";
    private static final String SFTP = "sftp";
    
    public static ChannelSftp getSftpConnection(final String username, final String hostname, final int port, final String password) throws JSchException {
        final Properties config = new Properties();
        config.put("StrictHostKeyChecking", "no");
        final JSch ssh = new JSch();
        final Session session = ssh.getSession(username, hostname, port);
        session.setConfig(config);
        session.setPassword(password);
        session.connect();
        final ChannelSftp channelSftp = (ChannelSftp)session.openChannel("sftp");
        channelSftp.connect();
        SFTPService.LOG.info((Object)"SFTP connected successfully");
        return channelSftp;
    }
    
    public static ChannelSftp getSftpConnectionWithPrivateKey(final String username, final String hostname, final int port, final String password, final String privateKeyPath) throws JSchException {
        final Properties config = new Properties();
        config.put("StrictHostKeyChecking", "no");
        final JSch ssh = new JSch();
        if (!isEmpty(privateKeyPath)) {
            ssh.addIdentity(privateKeyPath);
        }
        final Session session = ssh.getSession(username, hostname, port);
        session.setConfig(config);
        session.setPassword(password);
        session.connect();
        final ChannelSftp channelSftp = (ChannelSftp)session.openChannel("sftp");
        channelSftp.connect();
        SFTPService.LOG.info((Object)"SFTP connected successfully using private key");
        return channelSftp;
    }
    
    public static boolean isEmpty(final String param) {
        return param == null || param.trim().equalsIgnoreCase("null") || param.trim().isBlank() || param.trim().isEmpty();
    }
    
    public static void uploadStoredFile(final ChannelSftp channelSftp, final String srcFilelocation, final String disFileLocation) throws SftpException {
        channelSftp.put(srcFilelocation, disFileLocation);
        SFTPService.LOG.info("SFTP (uploadStoredFile) - File uploaded successfully at " + disFileLocation);
    }
    
    public static Set<String> getFolderFiles(final ChannelSftp channelSftp, final String directory, final String format) throws SftpException {
        final HashSet<String> fileList = new HashSet<String>();
        channelSftp.cd(directory);
        final Vector<ChannelSftp.LsEntry> srcFileList = channelSftp.ls("*." + format);
        SFTPService.LOG.info("SFTP (getFolderFiles) - Number. of files at " + directory + " is " + srcFileList.size());
        for (final ChannelSftp.LsEntry entry : srcFileList) {
            fileList.add(entry.getFilename());
        }
        return fileList;
    }
    
    public static void uploadFile(final ChannelSftp channelSftp, final String fileContent, final String distinationFileLocation) throws SftpException {
        channelSftp.put((InputStream)new ByteArrayInputStream(fileContent.getBytes()), distinationFileLocation);
        SFTPService.LOG.info((Object)"SFTP (uploadFile) - File uploaded successfully");
    }
    
    public static void disconnectChannelSftp(final ChannelSftp channelSftp) throws JSchException {
        if (channelSftp == null) {
            return;
        }
        if (channelSftp.isConnected()) {
            channelSftp.disconnect();
        }
        if (channelSftp.getSession() != null) {
            channelSftp.getSession().disconnect();
        }
        SFTPService.LOG.info((Object)"SFTP disconnected successfully");
    }
    
    static {
        LOG = Logger.getLogger((Class)SFTPService.class);
    }
}
